@@ -69,7 +69,8 @@ def search(api, conf, args):
     else:
         resp = api.search(args.query, limit=500000)
     print('Search for query \'%s\' : %s results' % (args.query, resp['total']))
-    sortlst = sort_torrents(resp['torrents'], args.sort, args.order)
+    cleanlst = [e for e in resp['torrents'] if isinstance(e, dict)]
+    sortlst = sort_torrents(cleanlst, args.sort, args.order)
     display_list(sortlst, conf['config']['limit'])
 
 
